@@ -7,7 +7,7 @@ usage example:
     input:
         import freq_note_converter
 
-        val = freq_note_converter.convert(freq=449)
+        val = freq_note_converter.from_freq(449)
         print(val.note)
     output:
         'A'
@@ -15,16 +15,16 @@ usage example:
         print(val)
     output:
                     freq : 449
-             note_number : 49
+             note_index : 49
                     note : A
                   octave : 4
         offset_from_note : 0.351
         --------------------------------------------------
     input:
-        freq_note_converter.convert(note_number=49).print_me()
+        freq_note_converter.from_note_index(49).print_me()
     output:
                     freq : 440.0
-             note_number : 49
+             note_index : 49
                     note : A
                   octave : 4
         offset_from_note : 0
@@ -33,11 +33,19 @@ usage example:
 from freq_note_converter import converter_code
 
 
-def convert(freq=None, note_number=None):
+def from_freq(freq):
+    return _convert(freq=freq)
+
+
+def from_note_index(note_index):
+    return _convert(note_index=note_index)
+
+
+def _convert(freq=None, note_index=None):
     if freq is not None:
         converter = converter_code.FreqNoteConverter(freq=freq)
-    elif note_number is not None:
-        converter = converter_code.FreqNoteConverter(note_number=note_number)
+    elif note_index is not None:
+        converter = converter_code.FreqNoteConverter(note_index=note_index)
     else:
         print('no valid input')
     return converter
